@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '9.991';
+our $VERSION = '9.992';
 $VERSION = eval $VERSION;
 
 require WWW::Shorten::_dead;
@@ -13,11 +13,11 @@ require WWW::Shorten::_dead;
 
 =head1 NAME
 
-WWW::Shorten::NotLong - Shorten URLs
+WWW::Shorten::NotLong - (DEPRECATED) Shorten URLs
 
 =head1 SYNOPSIS
 
-  # no viable UserAgent
+  # no viable use case
 
 =head1 DESCRIPTION
 
@@ -32,11 +32,17 @@ Eric Hammond C<ehammond@thinksome.com>
 
 =over
 
-=item Chase Whitener C<capoeirab@cpan.org> -- current maintainer
+=item *
 
-=item Dave Cross C<dave@perlhacks.com>
+Chase Whitener C<capoeirab@cpan.org>
 
-=item Iain Truskett C<spoon@cpan.org>
+=item *
+
+Dave Cross C<dave@perlhacks.com>
+
+=item *
+
+Iain Truskett C<spoon@cpan.org>
 
 =back
 
